pub enum PathElement {
PathClass(PathClass),
String(String),
}Expand description
The complete path of the current url, broken down into segments. A segment could be a string, or a path variable.
Variants