pub struct ProxyConfig {
pub disabled: Option<bool>,
pub host: Option<String>,
pub proxy_config_match: Option<String>,
pub port: Option<i64>,
pub tunnel: Option<bool>,
}Expand description
Using the Proxy, you can configure your custom proxy into the postman for particular url match
Fields
disabled: Option<bool>When set to true, ignores this proxy configuration entity
host: Option<String>The proxy server host
proxy_config_match: Option<String>The Url match for which the proxy config is defined
port: Option<i64>The proxy server port
tunnel: Option<bool>The tunneling details for the proxy config